# Documentation

Please see the [following documentation for Requirements, install and usage](https://doc.nuxeo.com/n/Kvd)

# License

[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0.html)

# Localization

Translations are managed with [Crowdin](https://crowdin.com/).

The reference file [message.json](https://github.com/nuxeo/nuxeo-aspera-connector/blob/master/nuxeo-aspera-web/src/main/resources/web/nuxeo.war/ui/i18n/messages.json) contains the labels and the English values.

Translations for other languages are managed in the [nuxeo-aspera](https://crowdin.com/project/nuxeo-aspera) Crowdin project, e.g. [French](https://crowdin.com/translate/nuxeo-aspera/4/en-fr).

The [nuxeo-aspera-connector](https://jenkins.napps.dev.nuxeo.com/job/nuxeo/job/crowdin/job/nuxeo-aspera-connector/) Jenkins job triggers a daily synchronization of:
- The messages.json reference file to Crowdin. This file can be edited and changes must be pushed to the current repository.
- The Crowdin translation files are located in the i18n folder (e.g. messages-fr.json). These files must never be edited from the source tree.

# Development Workflow
Nuxeo Aspera Connector is an addon that can be plugged to Nuxeo.
This repository contains the backend and frontend contributions for the [Nuxeo Platform](https://github.com/nuxeo/nuxeo) and [Nuxeo Web UI](https://github.com/nuxeo/nuxeo-web-ui).

Nuxeo Aspera Connector code is bundled as a [marketplace package](https://connect.nuxeo.com/nuxeo/site/marketplace/package/nuxeo-aspera) that includes all the backend and frontend contributions.

## UI
Frontend contributions are located under `nuxeo-aspera-web` and its subfolders map Nuxeo server's folder structure.

**_Disclaimer:_** In order to contribute and develop Nuxeo Aspera Connector UI, it is assumed that there is a Nuxeo server running with Nuxeo Aspera Connector package installed and properly configured according the documentation above.

### Install Dependencies
Some dev dependencies in order to have the ability to lint code and to sync code with Nuxeo server while developing and changing the existing code base.

```sh
npm install
```

### Linting & Code Style
The UI contribution has linting to help making the code simpler and safer.

```sh
npm run lint
```

To help on code style and formatting the following command is available. 

```sh
npm run format
```

Both `lint` and `format` commands run automatically before performing a commit in order to help us keeping the code base consistent with the rules defined.

### Sync
To simplify the developers flow the `sync` command is available to help synchronizing content between our code checkout and Nuxeo server.

```sh
npm run sync --dest ${myServerNuxeoServerLocation}/nxserver/nuxeo.war/ui 
```

This command will basically copy local checkout files to the Nuxeo server location so developers can see immediately their changes by refreshing the page on http://0.0.0.0:8080/.

# About Nuxeo

The [Nuxeo Platform](http://www.nuxeo.com/products/content-management-platform/) is an open source customizable and extensible content management platform for building business applications. It provides the foundation for developing [document management](http://www.nuxeo.com/solutions/document-management/), [digital asset management](http://www.nuxeo.com/solutions/digital-asset-management/), [case management application](http://www.nuxeo.com/solutions/case-management/) and [knowledge management](http://www.nuxeo.com/solutions/advanced-knowledge-base/). You can easily add features using ready-to-use addons or by extending the platform using its extension point system.

The Nuxeo Platform is developed and supported by Nuxeo, with contributions from the community.

Nuxeo dramatically improves how content-based applications are built, managed and deployed, making customers more agile, innovative and successful. Nuxeo provides a next generation, enterprise ready platform for building traditional and cutting-edge content oriented applications. Combining a powerful application development environment with
SaaS-based tools and a modular architecture, the Nuxeo Platform and Products provide clear business value to some of the most recognizable brands including Verizon, Electronic Arts, Sharp, FICO, the U.S. Navy, and Boeing. Nuxeo is headquartered in New York and Paris.
More information is available at [www.nuxeo.com](http://www.nuxeo.com).

